@@ -29,8 +29,6 @@ test_that("mcmc_sample gracefully fails if cmdstanr is unavailable", {
   )
 })
 
-
-
 skip_if_not(check_cmdstan())
 
 # Error checking----
@@ -458,34 +456,87 @@ test_that("mcmc_sample for Analysis works for no borrowing, binomial dist, two c
   )
 })
 
-# Exponential models, BDB conservative----
-test_that("mcmc_sample for Analysis works for exponential BDB, conservative borrowing", {
+# Continuous normal models, Full Borrowing ----
+test_that("mcmc_sample for Analysis works for normal with full borrowing", {
   skip_on_cran()
   skip_on_ci()
-  exp_bdb_conservative <- create_analysis_obj(
-    data_matrix = example_matrix,
-    outcome = outcome_surv_exponential(
-      time_var = "time",
-      cens_var = "cnsr",
-      prior_normal(0, 100000)
-    ),
-    borrowing = borrowing_hierarchical_commensurate(
-      ext_flag_col = "ext",
-      tau_prior = prior_gamma(0.001, 0.001)
-    ),
-    treatment = treatment_details("trt", prior_normal(0, 100000))
+  set.seed(123)
+
+  outcome_col <- 5 + example_matrix[, "trt"] + example_matrix[, "cov1"] + 2 * example_matrix[, "cov2"] +
+    0.5 * example_matrix[, "cov3"] - 1.5 * example_matrix[, "cov4"] + rnorm(500, 0, 1)
+
+  outcome <- outcome_cont_normal(
+    continuous_var = "outcome",
+    baseline_prior = prior_normal(0, 100),
+    std_dev_prior=prior_half_cauchy(1, 5)
+  )
+  borrowing <- borrowing_full(
+    ext_flag_col = "ext"
+  )
+  treatment <- treatment_details(
+    trt_flag_col = "trt",
+    trt_prior = prior_normal(0, 1000)
+  )
+  anls_obj <- create_analysis_obj(
+    data_matrix = cbind(example_matrix, outcome = outcome_col),
+    outcome =  outcome,
+    borrowing = borrowing,
+    treatment = treatment,
+    quiet = FALSE
   )
   result <- mcmc_sample(
-    exp_bdb_conservative,
+    anls_obj,
     iter_warmup = 2000,
     iter_sampling = 2000,
     chains = 1
   )
 
-  result_summary <- result$summary("HR_trt")
-  expect_equal(result_summary[["median"]], 0.85, tolerance = .05)
-  expect_equal(result_summary[["q5"]], 0.62, tolerance = .05)
-  expect_equal(result_summary[["q95"]], 1.18, tolerance = .05)
+  result_summary <- result$summary(c("alpha", "beta_trt"))
+  expect_equal(result_summary[["median"]], c(6.58, 0.42), tolerance = .05)
+  expect_equal(result_summary[["q5"]], c(6.45, 0.128), tolerance = .05)
+  expect_equal(result_summary[["q95"]], c(6.72, 0.72), tolerance = .05)
+})
+
+# Continuous normal models, BDB ----
+test_that("mcmc_sample for Analysis works for normal with BDB", {
+  skip_on_cran()
+  skip_on_ci()
+  set.seed(123)
+
+  outcome_col <- 5 + example_matrix[, "trt"] + example_matrix[, "cov1"] + 2 * example_matrix[, "cov2"] +
+    0.5 * example_matrix[, "cov3"] - 1.5 * example_matrix[, "cov4"] + rnorm(500, 0, 1)
+
+  outcome <- outcome_cont_normal(
+    continuous_var = "outcome",
+    baseline_prior = prior_normal(0, 100),
+    std_dev_prior=prior_half_cauchy(1, 5)
+  )
+  borrowing <- borrowing_hierarchical_commensurate(
+    ext_flag_col = "ext",
+    tau_prior = prior_gamma(0.001, 0.001)
+  )
+  treatment <- treatment_details(
+    trt_flag_col = "trt",
+    trt_prior = prior_normal(0, 1000)
+  )
+  anls_obj <- create_analysis_obj(
+    data_matrix = cbind(example_matrix, outcome = outcome_col),
+    outcome =  outcome,
+    borrowing = borrowing,
+    treatment = treatment,
+    quiet = FALSE
+  )
+  result <- mcmc_sample(
+    anls_obj,
+    iter_warmup = 2000,
+    iter_sampling = 2000,
+    chains = 1
+  )
+
+  result_summary <- result$summary("beta_trt")
+  expect_equal(result_summary[["median"]], 1.20, tolerance = .05)
+  expect_equal(result_summary[["q5"]], 0.715, tolerance = .05)
+  expect_equal(result_summary[["q95"]], 1.71, tolerance = .05)
 })
 
 # Weibull models, BDB aggressive----
@@ -544,3 +595,121 @@ test_that("mcmc_sample for Analysis works for logistic regression BDB, aggressiv
   expect_equal(result_summary[["q5"]], 1.10, tolerance = .05)
   expect_equal(result_summary[["q95"]], 2.44, tolerance = .05)
 })
+
+
+# Piecewise exponential, no BDB ----
+test_that("mcmc_sample for Analysis works for full borrowing, piecewise exponential dist", {
+  skip_on_cran()
+  skip_on_ci()
+  library(eha)
+  cuts = c(1, 5, 10)
+  pem_eha <- eha::pchreg(survival::Surv(time, status) ~ trt + cov1 + cov2, data = as.data.frame(psborrow2::example_matrix), cuts = c(0, cuts, 1000))
+
+  full_pem_bayes_ao <- create_analysis_obj(
+    data_matrix = example_matrix,
+    outcome = outcome_surv_pem("time", "cnsr", prior_normal(0, 100000), cut_points = cuts),
+    borrowing = borrowing_full("ext"),
+    treatment = treatment_details("trt", prior_normal(0, 100000)),
+    covariates = add_covariates(c("cov1", "cov2"), prior_normal(0, 100000))
+  )
+
+  full_pem_bayes <- mcmc_sample(full_pem_bayes_ao,
+    iter_warmup = 2000,
+    iter_sampling = 5000,
+    chains = 2
+  )
+  expect_r6(full_pem_bayes, "CmdStanMCMC")
+  expect_equal(full_pem_bayes$summary("beta_trt")[[2]], pem_eha$coefficients[['trt']], tolerance = 0.05)
+  expect_equal(full_pem_bayes$summary("beta[1]")[[2]], pem_eha$coefficients[['cov1']], tolerance = 0.05)
+  expect_equal(full_pem_bayes$summary("beta[2]")[[2]], pem_eha$coefficients[['cov2']], tolerance = 0.05)
+
+  # Check that the cut points are the same
+  expect_equal(full_pem_bayes$summary("alpha[1]")[[2]], log(pem_eha$hazards[1]), tolerance = 0.05)
+  expect_equal(full_pem_bayes$summary("alpha[2]")[[2]], log(pem_eha$hazards[2]), tolerance = 0.05)
+  expect_equal(full_pem_bayes$summary("alpha[3]")[[2]], log(pem_eha$hazards[3]), tolerance = 0.05)
+  expect_equal(full_pem_bayes$summary("alpha[4]")[[2]], log(pem_eha$hazards[4]), tolerance = 0.05)
+
+})
+
+# Piecewise exponential, BDB ----
+test_that("mcmc_sample for Analysis works for BDB, piecewise exponential dist", {
+  skip_on_cran()
+  skip_on_ci()
+  cuts = c(1, 5, 10)
+
+  # Make commensurate matrix
+  internal_as_external <- example_matrix[example_matrix[, 'ext'] == 0 & example_matrix[,'trt'] == 0,]
+  internal_as_external[, 'ext'] <- 1
+  internal_as_external[, 'id'] <- seq(10000, 10000 + nrow(internal_as_external) - 1)
+  commensurate_matrix <- rbind(
+    example_matrix[example_matrix[,'ext'] == 0,],
+    internal_as_external
+  )
+
+  ## Conservative commensurate
+  bdb_pem_bayes_commens_conserv_ao <- create_analysis_obj(
+    data_matrix = commensurate_matrix,
+    outcome = outcome_surv_pem("time", "cnsr", prior_normal(0, 100000), cut_points = cuts),
+    borrowing = borrowing_hierarchical_commensurate("ext", prior_gamma(0.001, 0.001)),
+    treatment = treatment_details("trt", prior_normal(0, 100000))
+  )
+
+  bdb_pem_bayes_commens_conserv <- mcmc_sample(bdb_pem_bayes_commens_conserv_ao,
+    iter_warmup = 2000,
+    iter_sampling = 5000,
+    chains = 2
+  )
+  tau_commens_conserv <- bdb_pem_bayes_commens_conserv$summary("tau")[["median"]]
+
+  ## Conservative incommensurate
+  bdb_pem_bayes_incommens_conserv_ao <- create_analysis_obj(
+    data_matrix = example_matrix,
+    outcome = outcome_surv_pem("time", "cnsr", prior_normal(0, 100000), cut_points = cuts),
+    borrowing = borrowing_hierarchical_commensurate("ext", prior_gamma(0.001, 0.001)),
+    treatment = treatment_details("trt", prior_normal(0, 100000))
+  )
+
+  bdb_pem_bayes_incommens_conserv <- mcmc_sample(bdb_pem_bayes_incommens_conserv_ao,
+    iter_warmup = 2000,
+    iter_sampling = 5000,
+    chains = 2
+  )
+  tau_incommens_conserv <- bdb_pem_bayes_incommens_conserv$summary("tau")[["median"]]
+
+  ## Aggressive commensurate
+  bdb_pem_bayes_commens_aggr_ao <- create_analysis_obj(
+    data_matrix = commensurate_matrix,
+    outcome = outcome_surv_pem("time", "cnsr", prior_normal(0, 100000), cut_points = cuts),
+    borrowing = borrowing_hierarchical_commensurate("ext", prior_gamma(1, .001)),
+    treatment = treatment_details("trt", prior_normal(0, 100000))
+  )
+
+  bdb_pem_bayes_commens_aggr <- mcmc_sample(bdb_pem_bayes_commens_aggr_ao,
+    iter_warmup = 2000,
+    iter_sampling = 5000,
+    chains = 2
+  )
+  tau_commens_aggr <- bdb_pem_bayes_commens_aggr$summary("tau")[["median"]]
+
+  ## Aggressive incommensurate
+  bdb_pem_bayes_incommens_aggr_ao <- create_analysis_obj(
+    data_matrix = example_matrix,
+    outcome = outcome_surv_pem("time", "cnsr", prior_normal(0, 100000), cut_points = cuts),
+    borrowing = borrowing_hierarchical_commensurate("ext", prior_gamma(1, .001)),
+    treatment = treatment_details("trt", prior_normal(0, 100000))
+  )
+
+  bdb_pem_bayes_incommens_aggr <- mcmc_sample(bdb_pem_bayes_incommens_aggr_ao,
+    iter_warmup = 2000,
+    iter_sampling = 5000,
+    chains = 2
+  )
+  tau_incommens_aggr <- bdb_pem_bayes_incommens_aggr$summary("tau")[["median"]]
+
+  # Comparisons
+  expect_true(tau_commens_conserv > tau_incommens_conserv)
+  expect_true(tau_commens_aggr > tau_incommens_aggr)
+  expect_true(tau_commens_aggr > tau_commens_conserv)
+  expect_true(tau_incommens_aggr > tau_incommens_conserv)
+
+})
